==> tsml-eval-0.1.0.tar.gz: tsml-eval-0.1.0/docs/user_guide.md <==
# User Guide

::::{grid} 1 2 2 2
:gutter: 3

:::{grid-item-card}
:img-top: examples/images/wip.png
:text-align: center

tsml-eval Data Format

^^^

Placeholder.

+++

```{button-ref} /examples/datasets.ipynb
:color: primary
:click-parent:
:expand:

Datasets
```

:::

:::{grid-item-card}
:img-top: examples/images/TSC.png
:text-align: center

Time Series Classification

^^^

Placeholder.

+++

```{button-ref} /examples/classification_experiments.ipynb
:color: primary
:click-parent:
:expand:

TSC
```

:::

:::{grid-item-card}
:img-top: examples/images/TSR.png
:text-align: center

Time Series Extrinsic Regression

^^^

Placeholder.

+++

```{button-ref} /examples/regression_experiments.ipynb
:color: primary
:click-parent:
:expand:

TSER
```

:::

:::{grid-item-card}
:img-top: examples/images/TSCL.png
:text-align: center

Time Series Clustering

^^^

Placeholder.

+++

```{button-ref} /examples/clustering_experiments.ipynb
:color: primary
:click-parent:
:expand:

TSCL
```

:::

:::{grid-item-card}
:img-top: examples/images/wip.png
:text-align: center

tsml-eval Results Evaluation

^^^

Placeholder.

+++

```{button-ref} /examples/evaluation.ipynb
:color: primary
:click-parent:
:expand:

Evaluation
```

:::

:::{grid-item-card}
:img-top: examples/images/wip.png
:text-align: center

tsml-eval Results Format

^^^

Placeholder.

+++

```{button-ref} /examples/results_format.ipynb
:color: primary
:click-parent:
:expand:

Results
```

:::

::::

```{toctree}
:hidden:

./examples/datasets.ipynb
./examples/classification_experiments.ipynb
./examples/regression_experiments.ipynb
./examples/clustering_experiments.ipynb
./examples/evaluation.ipynb
./examples/results_format.ipynb
```

==> tsml-eval-0.2.0.tar.gz: tsml-eval-0.2.0/docs/user_guide.md <==
# User Guide

::::{grid} 1 2 2 2
:gutter: 3

:::{grid-item-card}
:img-top: examples/images/data.png
:class-img-top: tsml-card-image
:text-align: center

tsml-eval Data Format

^^^

An overview of the datatypes used for `tsml-eval` experiments.

+++

```{button-ref} /examples/datasets.ipynb
:color: primary
:click-parent:
:expand:

Datasets
```

:::

:::{grid-item-card}
:img-top: examples/images/cd_diagram.png
:class-img-top: tsml-card-image
:text-align: center

tsml-eval Results Evaluation

^^^

Use the `tsml-eval` package to evaluate your results.

+++

```{button-ref} /examples/evaluation.ipynb
:color: primary
:click-parent:
:expand:

Evaluation
```

:::

:::{grid-item-card}
:img-top: examples/images/results.png
:class-img-top: tsml-card-image
:text-align: center

tsml-eval Results Format

^^^

An overview of the results format output by `tsml-eval` experiments.

+++

```{button-ref} /examples/results_format.ipynb
:color: primary
:click-parent:
:expand:

Results
```

:::

:::{grid-item-card}
:img-top: examples/images/TSC.png
:class-img-top: tsml-card-image
:text-align: center

Time Series Classification

^^^

TODO Placeholder.

+++

```{button-ref} /examples/classification_experiments.ipynb
:color: primary
:click-parent:
:expand:

TSC
```

:::

:::{grid-item-card}
:img-top: examples/images/TSR.png
:class-img-top: tsml-card-image
:text-align: center

Time Series Extrinsic Regression

^^^

TODO Placeholder.

+++

```{button-ref} /examples/regression_experiments.ipynb
:color: primary
:click-parent:
:expand:

TSER
```

:::

:::{grid-item-card}
:img-top: examples/images/TSCL.png
:class-img-top: tsml-card-image
:text-align: center

Time Series Clustering

^^^

TODO Placeholder.

+++

```{button-ref} /examples/clustering_experiments.ipynb
:color: primary
:click-parent:
:expand:

TSCL
```

:::

:::{grid-item-card}
:img-top: examples/images/forecasting.png
:class-img-top: tsml-card-image
:text-align: center

Time Series Forecasting

^^^

TODO Placeholder.

+++

```{button-ref} /examples/forecasting_experiments.ipynb
:color: primary
:click-parent:
:expand:

Forecasting
```

:::

::::

```{toctree}
:hidden:

./examples/datasets.ipynb
./examples/evaluation.ipynb
./examples/results_format.ipynb
./examples/classification_experiments.ipynb
./examples/regression_experiments.ipynb
./examples/clustering_experiments.ipynb
./examples/forecasting_experiments.ipynb
```
